@@ -12,6 +12,7 @@ from polity.static import (
     FINANCIAL_STATEMENT_QUERY,
     DATASET_QUERY,
     COMPANY_QUERY,
+    EQUITIES_MESSAGES_QUERY,
     API_URL,
     EQUITIES_PUBLIC_API_KEY,
     COMPANY_SCHEMA    
@@ -59,6 +60,9 @@ class Client():
         )
         return graphql
 
+    def _fetch_equities_messages(self):
+        query = gql.gql(EQUITIES_MESSAGES_QUERY)
+        return self.graphql.execute(query)['equitiesMessages']
 
     def _fetch_dataset_to_desc_map(self):
         query = gql.gql(DATASET_NAME_DESC_QUERY)
