@@ -25,6 +25,11 @@ COMPANY_CIK_TICKER_QUERY = '''
         }
     }'''
 
+EQUITIES_MESSAGES_QUERY = '''
+    query {
+        equitiesMessages
+    }'''
+
 DATASET_QUERY = lambda name, api_key : '''
     query {
         dataset(name:"%s","%s"){
@@ -40,6 +45,7 @@ COMPANY_QUERY = lambda cik, api_key : '''
     query {
         company(cik:"%s",apiKey : "%s"){
             name
+            ticker
             sic 
             countryba
             cityba
